module Census2010DecSf1
  EXAMPLES = [
    ["H001001", "US:*"],
    ["H001001", "US:1"],
    ["H001001", "REGION:*"],
    ["H001001", "REGION:1"],
    ["H001001", "DIVISION:*"],
    ["H001001", "DIVISION:1"],
    ["H001001", "STATE:*"],
    ["H001001", "STATE:01"],
    ["H001001", "COUNTY:*", ["STATE:*"]],
    ["H001001", "COUNTY:*", ["STATE:02"]],
    ["H001001", "COUNTY:013", ["STATE:02"]],
    ["H001001", "COUSUB:*", ["STATE:36", "COUNTY:029"]],
    ["H001001", "COUSUB:01099", ["STATE:36", "COUNTY:029"]],
    ["H001001", "SUBMCD:*", ["STATE:72", "COUNTY:075", "COUSUB:39015"]],
    ["H001001", "SUBMCD:64965", ["STATE:72", "COUNTY:075", "COUSUB:39015"]],
    ["H001001", "place/remainder%20(or%20part):*", ["STATE:72", "COUNTY:065", "COUSUB:20525"]],
    ["H001001", "place/remainder%20(or%20part):68556", ["STATE:72", "COUNTY:065", "COUSUB:20525"]],
    ["H001001", "tract%20(or%20part):*", ["STATE:01", "COUNTY:051", "COUSUB:93087", "place/remainder%20(or%20part):23880"]],
    ["H001001", "tract%20(or%20part):030400", ["STATE:01", "COUNTY:051", "COUSUB:93087", "place/remainder%20(or%20part):23880"]],
    ["H001001", "UR:*", ["STATE:01", "COUNTY:087", "COUSUB:93230", "place/remainder%20(or%20part):77304", "tract%20(or%20part):231900"]],
    ["H001001", "UR:R", ["STATE:01", "COUNTY:087", "COUSUB:93230", "place/remainder%20(or%20part):77304", "tract%20(or%20part):231900"]],
    ["H001001", "UR:*", ["STATE:01", "COUNTY:089", "COUSUB:92349", "place/remainder%20(or%20part):37000", "tract%20(or%20part):011300", "block%20group%20(or%20part):1"]],
    ["H001001", "UR:U", ["STATE:01", "COUNTY:089", "COUSUB:92349", "place/remainder%20(or%20part):37000", "tract%20(or%20part):011300", "block%20group%20(or%20part):1"]],
    ["H001001", "block%20group%20(or%20part):*", ["STATE:04", "COUNTY:013", "COUSUB:92601", "place/remainder%20(or%20part):65000", "tract%20(or%20part):216836"]],
    ["H001001", "block%20group%20(or%20part):1", ["STATE:04", "COUNTY:013", "COUSUB:92601", "place/remainder%20(or%20part):65000", "tract%20(or%20part):216836"]],
    ["H001001", "TABBLOCK:*", ["STATE:01", "COUNTY:009", "TRACT:*"]],
    ["H001001", "TABBLOCK:*", ["STATE:01", "COUNTY:009", "TRACT:050602"]],
    ["H001001", "TABBLOCK:1030", ["STATE:01", "COUNTY:009", "TRACT:050602"]],
    ["H001001", "TRACT:*", ["STATE:01", "COUNTY:001"]],
    ["H001001", "TRACT:020500", ["STATE:01", "COUNTY:001"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):*", ["STATE:01", "COUNTY:031", "TRACT:010100"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9820", ["STATE:01", "COUNTY:031", "TRACT:010100"]],
    ["H001001", "BG:*", ["STATE:01", "COUNTY:073", "TRACT:011804"]],
    ["H001001", "BG:1", ["STATE:01", "COUNTY:073", "TRACT:011804"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):*", ["STATE:01", "COUNTY:109", "TRACT:189000", "BG:5"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9880", ["STATE:01", "COUNTY:109", "TRACT:189000", "BG:5"]],
    ["H001001", "county%20(or%20part):*", ["STATE:01", "PLACE:78480"]],
    ["H001001", "county%20(or%20part):075", ["STATE:01", "PLACE:78480"]],
    ["H001001", "tract%20(or%20part):*", ["STATE:01", "PLACE:57648", "county%20(or%20part):045"]],
    ["H001001", "tract%20(or%20part):020400", ["STATE:01", "PLACE:57648", "county%20(or%20part):045"]],
    ["H001001", "place%20(or%20part):*", ["STATE:31", "COUNTY:169"]],
    ["H001001", "place%20(or%20part):23410", ["STATE:31", "COUNTY:169"]],
    ["H001001", "PLACE:*", ["STATE:*"]],
    ["H001001", "PLACE:*", ["STATE:01"]],
    ["H001001", "PLACE:35536", ["STATE:01"]],
    ["H001001", "CONCITY:*", ["STATE:*"]],
    ["H001001", "CONCITY:*", ["STATE:21"]],
    ["H001001", "CONCITY:48003", ["STATE:21"]],
    ["H001001", "place%20(or%20part):*", ["STATE:13", "CONCITY:03436"]],
    ["H001001", "place%20(or%20part):09068", ["STATE:13", "CONCITY:03436"]],
    ["H001001", "ANRC:*", ["STATE:*"]],
    ["H001001", "ANRC:*", ["STATE:02"]],
    ["H001001", "ANRC:67940", ["STATE:02"]],
    ["H001001", "AIANNH:*"],
    ["H001001", "AIANNH:6815"],
    ["H001001", "AITS:*", ["AIANNH:2430"]],
    ["H001001", "AITS:325", ["AIANNH:2430"]],
    ["H001001", "AIAANA:*", ["AIANNH:*"]],
    ["H001001", "AIAANA:*", ["AIANNH:0695"]],
    ["H001001", "AIAANA:R", ["AIANNH:0695"]],
    ["H001001", "american%20indian%20tribal%20subdivision%20(or%20part):*", ["AIANNH:3970", "AIAANA:R"]],
    ["H001001", "american%20indian%20tribal%20subdivision%20(or%20part):400", ["AIANNH:3970", "AIAANA:R"]],
    ["H001001", "AIAHHL:*", ["AIANNH:5133"]],
    ["H001001", "AIAHHL:T", ["AIANNH:5133"]],
    ["H001001", "american%20indian%20tribal%20subdivision%20(or%20part):*", ["AIANNH:2430", "AIAHHL:T"]],
    ["H001001", "american%20indian%20tribal%20subdivision%20(or%20part):030", ["AIANNH:2430", "AIAHHL:T"]],
    ["H001001", "TTRACT:*", ["AIANNH:2430"]],
    ["H001001", "TTRACT:T01100", ["AIANNH:2430"]],
    ["H001001", "tribal%20census%20tract%20(or%20part):*", ["AIANNH:1160", "AITS:800"]],
    ["H001001", "tribal%20census%20tract%20(or%20part):T00200", ["AIANNH:1160", "AITS:800"]],
    ["H001001", "TBG:*", ["AIANNH:2445", "TTRACT:T00200"]],
    ["H001001", "TBG:A", ["AIANNH:2445", "TTRACT:T00200"]],
    ["H001001", "state%20(or%20part):*", ["AIANNH:7425"]],
    ["H001001", "state%20(or%20part):02", ["AIANNH:7425"]],
    ["H001001", "county%20subdivision%20(or%20part):*", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2865", "county%20(or%20part):053"]],
    ["H001001", "county%20subdivision%20(or%20part):90153", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2865", "county%20(or%20part):053"]],
    ["H001001", "state%20(or%20part):*", ["AIANNH:6550", "AIAANA:R"]],
    ["H001001", "state%20(or%20part):02", ["AIANNH:6550", "AIAANA:R"]],
    ["H001001", "place/remainder%20(or%20part):*", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9550", "county%20(or%20part):069", "county%20subdivision%20(or%20part):90702"]],
    ["H001001", "place/remainder%20(or%20part):99999", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9550", "county%20(or%20part):069", "county%20subdivision%20(or%20part):90702"]],
    ["H001001", "state%20(or%20part):*", ["AIANNH:2145", "AIAHHL:T"]],
    ["H001001", "state%20(or%20part):09", ["AIANNH:2145", "AIAHHL:T"]],
    ["H001001", "county%20subdivision%20(or%20part):*", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9680", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R", "county%20(or%20part):089"]],
    ["H001001", "county%20subdivision%20(or%20part):91575", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9680", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R", "county%20(or%20part):089"]],
    ["H001001", "place/remainder%20(or%20part):*", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9880", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R", "county%20(or%20part):109", "county%20subdivision%20(or%20part):90198"]],
    ["H001001", "place/remainder%20(or%20part):03940", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9880", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R", "county%20(or%20part):109", "county%20subdivision%20(or%20part):90198"]],
    ["H001001", "county%20subdivision%20(or%20part):*", ["STATE:06", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):0120", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T", "county%20(or%20part):061"]],
    ["H001001", "county%20subdivision%20(or%20part):91605", ["STATE:06", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):0120", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T", "county%20(or%20part):061"]],
    ["H001001", "place/remainder%20(or%20part):*", ["STATE:06", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):0620", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T", "county%20(or%20part):109", "county%20subdivision%20(or%20part):93080"]],
    ["H001001", "place/remainder%20(or%20part):99999", ["STATE:06", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):0620", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T", "county%20(or%20part):109", "county%20subdivision%20(or%20part):93080"]],
    ["H001001", "place%20(or%20part):*", ["AIANNH:2865", "state%20(or%20part):01"]],
    ["H001001", "place%20(or%20part):99999", ["AIANNH:2865", "state%20(or%20part):01"]],
    ["H001001", "county%20(or%20part):*", ["AIANNH:9880", "state%20(or%20part):01"]],
    ["H001001", "county%20(or%20part):109", ["AIANNH:9880", "state%20(or%20part):01"]],
    ["H001001", "county%20subdivision%20(or%20part):*", ["AIANNH:2865", "state%20(or%20part):01", "county%20(or%20part):051"]],
    ["H001001", "county%20subdivision%20(or%20part):93456", ["AIANNH:2865", "state%20(or%20part):01", "county%20(or%20part):051"]],
    ["H001001", "county%20(or%20part):*", ["AIANNH:2865", "AIAANA:R", "state%20(or%20part):01"]],
    ["H001001", "county%20(or%20part):053", ["AIANNH:2865", "AIAANA:R", "state%20(or%20part):01"]],
    ["H001001", "place%20(or%20part):*", ["AIANNH:9240", "state%20(or%20part):01", "county%20(or%20part):129", "county%20subdivision%20(or%20part):92043"]],
    ["H001001", "place%20(or%20part):99999", ["AIANNH:9240", "state%20(or%20part):01", "county%20(or%20part):129", "county%20subdivision%20(or%20part):92043"]],
    ["H001001", "county%20(or%20part):*", ["AIANNH:3735", "AIAHHL:T", "state%20(or%20part):06"]],
    ["H001001", "county%20(or%20part):045", ["AIANNH:3735", "AIAHHL:T", "state%20(or%20part):06"]],
    ["H001001", "county%20subdivision%20(or%20part):*", ["AIANNH:9240", "AIAANA:R", "state%20(or%20part):01", "county%20(or%20part):129"]],
    ["H001001", "county%20subdivision%20(or%20part):92043", ["AIANNH:9240", "AIAANA:R", "state%20(or%20part):01", "county%20(or%20part):129"]],
    ["H001001", "place%20(or%20part):*", ["AIANNH:9550", "AIAANA:R", "state%20(or%20part):01", "county%20(or%20part):069", "county%20subdivision%20(or%20part):90747"]],
    ["H001001", "place%20(or%20part):17824", ["AIANNH:9550", "AIAANA:R", "state%20(or%20part):01", "county%20(or%20part):069", "county%20subdivision%20(or%20part):90747"]],
    ["H001001", "county%20subdivision%20(or%20part):*", ["AIANNH:3855", "AIAHHL:T", "state%20(or%20part):06", "county%20(or%20part):015"]],
    ["H001001", "county%20subdivision%20(or%20part):93040", ["AIANNH:3855", "AIAHHL:T", "state%20(or%20part):06", "county%20(or%20part):015"]],
    ["H001001", "place/remainder%20(or%20part):*", ["AIANNH:3735", "AIAHHL:T", "state%20(or%20part):06", "county%20(or%20part):045", "county%20subdivision%20(or%20part):93740"]],
    ["H001001", "place/remainder%20(or%20part):99999", ["AIANNH:3735", "AIAHHL:T", "state%20(or%20part):06", "county%20(or%20part):045", "county%20subdivision%20(or%20part):93740"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):*", ["STATE:02"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):6525", ["STATE:02"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):*", ["STATE:04", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):350", ["STATE:04", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430"]],
    ["H001001", "county%20(or%20part):*", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2865"]],
    ["H001001", "county%20(or%20part):051", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2865"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):*", ["STATE:02", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):7430"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R", ["STATE:02", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):7430"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):*", ["STATE:04", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):250", ["STATE:04", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R"]],
    ["H001001", "county%20(or%20part):*", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9880", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R"]],
    ["H001001", "county%20(or%20part):109", ["STATE:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9880", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R"]],
    ["H001001", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):*", ["STATE:04", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430"]],
    ["H001001", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T", ["STATE:04", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):*", ["STATE:04", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):170", ["STATE:04", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T"]],
    ["H001001", "county%20(or%20part):*", ["STATE:06", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):0020", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T"]],
    ["H001001", "county%20(or%20part):065", ["STATE:06", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):0020", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T"]],
    ["H001001", "state%20(or%20part):*", ["AIANNH:3340", "AITS:700"]],
    ["H001001", "state%20(or%20part):04", ["AIANNH:3340", "AITS:700"]],
    ["H001001", "tribal%20census%20tract%20(or%20part):*", ["AIANNH:4290", "AIAANA:R"]],
    ["H001001", "tribal%20census%20tract%20(or%20part):T00300", ["AIANNH:4290", "AIAANA:R"]],
    ["H001001", "tribal%20census%20tract%20(or%20part):*", ["AIANNH:4315", "AIAHHL:T"]],
    ["H001001", "tribal%20census%20tract%20(or%20part):T00100", ["AIANNH:4315", "AIAHHL:T"]],
    ["H001001", "tribal%20block%20group%20(or%20part):*", ["AIANNH:3355", "AIAANA:R", "tribal%20census%20tract%20(or%20part):T00100"]],
    ["H001001", "tribal%20block%20group%20(or%20part):B", ["AIANNH:3355", "AIAANA:R", "tribal%20census%20tract%20(or%20part):T00100"]],
    ["H001001", "tribal%20block%20group%20(or%20part):*", ["AIANNH:3020", "AIAHHL:T", "tribal%20census%20tract%20(or%20part):T00100"]],
    ["H001001", "tribal%20block%20group%20(or%20part):A", ["AIANNH:3020", "AIAHHL:T", "tribal%20census%20tract%20(or%20part):T00100"]],
    ["H001001", "CBSA:*"],
    ["H001001", "CBSA:10420"],
    ["H001001", "state%20(or%20part):*", ["CBSA:33660"]],
    ["H001001", "state%20(or%20part):01", ["CBSA:33660"]],
    ["H001001", "principal%20city%20(or%20part):*", ["CBSA:*"]],
    ["H001001", "principal%20city%20(or%20part):*", ["CBSA:10740"]],
    ["H001001", "principal%20city%20(or%20part):02000", ["CBSA:10740"]],
    ["H001001", "COUNTY:*", ["CBSA:19300", "state%20(or%20part):01"]],
    ["H001001", "COUNTY:003", ["CBSA:19300", "state%20(or%20part):01"]],
    ["H001001", "METDIV:*", ["CBSA:*"]],
    ["H001001", "METDIV:*", ["CBSA:31100"]],
    ["H001001", "METDIV:31084", ["CBSA:31100"]],
    ["H001001", "state%20(or%20part):*", ["CBSA:47900", "METDIV:13644"]],
    ["H001001", "state%20(or%20part):24", ["CBSA:47900", "METDIV:13644"]],
    ["H001001", "COUNTY:*", ["CBSA:16980", "METDIV:16974", "state%20(or%20part):17"]],
    ["H001001", "COUNTY:037", ["CBSA:16980", "METDIV:16974", "state%20(or%20part):17"]],
    ["H001001", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):*", ["STATE:*"]],
    ["H001001", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):*", ["STATE:01"]],
    ["H001001", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):10700", ["STATE:01"]],
    ["H001001", "principal%20city%20(or%20part):*", ["STATE:01", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):10760"]],
    ["H001001", "principal%20city%20(or%20part):01132", ["STATE:01", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):10760"]],
    ["H001001", "COUNTY:*", ["STATE:01", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):10700"]],
    ["H001001", "COUNTY:095", ["STATE:01", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):10700"]],
    ["H001001", "metropolitan%20division%20(or%20part):*", ["STATE:24", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):47900"]],
    ["H001001", "metropolitan%20division%20(or%20part):13644", ["STATE:24", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):47900"]],
    ["H001001", "COUNTY:*", ["STATE:17", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):16980", "metropolitan%20division%20(or%20part):16974"]],
    ["H001001", "COUNTY:037", ["STATE:17", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):16980", "metropolitan%20division%20(or%20part):16974"]],
    ["H001001", "CSA:*"],
    ["H001001", "CSA:104"],
    ["H001001", "state%20(or%20part):*", ["CSA:278"]],
    ["H001001", "state%20(or%20part):09", ["CSA:278"]],
    ["H001001", "CBSA:*", ["CSA:294"]],
    ["H001001", "CBSA:35220", ["CSA:294"]],
    ["H001001", "state%20(or%20part):*", ["CSA:308", "CBSA:27860"]],
    ["H001001", "state%20(or%20part):05", ["CSA:308", "CBSA:27860"]],
    ["H001001", "CNECTA:*"],
    ["H001001", "CNECTA:715"],
    ["H001001", "state%20(or%20part):*", ["CNECTA:715"]],
    ["H001001", "state%20(or%20part):09", ["CNECTA:715"]],
    ["H001001", "NECTA:*", ["CNECTA:710"]],
    ["H001001", "NECTA:78850", ["CNECTA:710"]],
    ["H001001", "state%20(or%20part):*", ["CNECTA:720", "NECTA:78700"]],
    ["H001001", "state%20(or%20part):09", ["CNECTA:720", "NECTA:78700"]],
    ["H001001", "combined%20statistical%20area%20(or%20part):*", ["STATE:*"]],
    ["H001001", "combined%20statistical%20area%20(or%20part):*", ["STATE:41"]],
    ["H001001", "combined%20statistical%20area%20(or%20part):140", ["STATE:41"]],
    ["H001001", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):*", ["STATE:01", "combined%20statistical%20area%20(or%20part):142"]],
    ["H001001", "metropolitan%20statistical%20area/micropolitan%20statistical%20area%20(or%20part):18980", ["STATE:01", "combined%20statistical%20area%20(or%20part):142"]],
    ["H001001", "combined%20new%20england%20city%20and%20town%20area%20(or%20part):*", ["STATE:*"]],
    ["H001001", "combined%20new%20england%20city%20and%20town%20area%20(or%20part):*", ["STATE:09"]],
    ["H001001", "combined%20new%20england%20city%20and%20town%20area%20(or%20part):715", ["STATE:09"]],
    ["H001001", "new%20england%20city%20and%20town%20area%20(or%20part):*", ["STATE:09", "combined%20new%20england%20city%20and%20town%20area%20(or%20part):720"]],
    ["H001001", "new%20england%20city%20and%20town%20area%20(or%20part):78700", ["STATE:09", "combined%20new%20england%20city%20and%20town%20area%20(or%20part):720"]],
    ["H001001", "NECTA:*"],
    ["H001001", "NECTA:71650"],
    ["H001001", "state%20(or%20part):*", ["NECTA:71950"]],
    ["H001001", "state%20(or%20part):09", ["NECTA:71950"]],
    ["H001001", "PCITY:*", ["NECTA:*"]],
    ["H001001", "PCITY:*", ["NECTA:71950"]],
    ["H001001", "PCITY:73000", ["NECTA:71950"]],
    ["H001001", "county%20(or%20part):*", ["NECTA:78100", "state%20(or%20part):09"]],
    ["H001001", "county%20(or%20part):013", ["NECTA:78100", "state%20(or%20part):09"]],
    ["H001001", "COUSUB:*", ["NECTA:79600", "state%20(or%20part):09", "county%20(or%20part):015"]],
    ["H001001", "COUSUB:75870", ["NECTA:79600", "state%20(or%20part):09", "county%20(or%20part):015"]],
    ["H001001", "NECTADIV:*", ["NECTA:71650"]],
    ["H001001", "NECTADIV:71654", ["NECTA:71650"]],
    ["H001001", "state%20(or%20part):*", ["NECTA:71650", "NECTADIV:75404"]],
    ["H001001", "state%20(or%20part):33", ["NECTA:71650", "NECTADIV:75404"]],
    ["H001001", "county%20(or%20part):*", ["NECTA:71650", "NECTADIV:73604", "state%20(or%20part):25"]],
    ["H001001", "county%20(or%20part):009", ["NECTA:71650", "NECTADIV:73604", "state%20(or%20part):25"]],
    ["H001001", "COUSUB:*", ["NECTA:71650", "NECTADIV:76524", "state%20(or%20part):25", "county%20(or%20part):009"]],
    ["H001001", "COUSUB:37490", ["NECTA:71650", "NECTADIV:76524", "state%20(or%20part):25", "county%20(or%20part):009"]],
    ["H001001", "new%20england%20city%20and%20town%20area%20(or%20part):*", ["STATE:*"]],
    ["H001001", "new%20england%20city%20and%20town%20area%20(or%20part):*", ["STATE:23"]],
    ["H001001", "new%20england%20city%20and%20town%20area%20(or%20part):70600", ["STATE:23"]],
    ["H001001", "PCITY:*", ["STATE:09", "new%20england%20city%20and%20town%20area%20(or%20part):71950"]],
    ["H001001", "PCITY:47515", ["STATE:09", "new%20england%20city%20and%20town%20area%20(or%20part):71950"]],
    ["H001001", "county%20(or%20part):*", ["STATE:09", "new%20england%20city%20and%20town%20area%20(or%20part):71950"]],
    ["H001001", "county%20(or%20part):001", ["STATE:09", "new%20england%20city%20and%20town%20area%20(or%20part):71950"]],
    ["H001001", "COUSUB:*", ["STATE:09", "new%20england%20city%20and%20town%20area%20(or%20part):76450", "county%20(or%20part):011"]],
    ["H001001", "COUSUB:73770", ["STATE:09", "new%20england%20city%20and%20town%20area%20(or%20part):76450", "county%20(or%20part):011"]],
    ["H001001", "necta%20division%20(or%20part):*", ["STATE:33", "new%20england%20city%20and%20town%20area%20(or%20part):71650"]],
    ["H001001", "necta%20division%20(or%20part):75404", ["STATE:33", "new%20england%20city%20and%20town%20area%20(or%20part):71650"]],
    ["H001001", "county%20(or%20part):*", ["STATE:25", "new%20england%20city%20and%20town%20area%20(or%20part):71650", "necta%20division%20(or%20part):76524"]],
    ["H001001", "county%20(or%20part):009", ["STATE:25", "new%20england%20city%20and%20town%20area%20(or%20part):71650", "necta%20division%20(or%20part):76524"]],
    ["H001001", "COUSUB:*", ["STATE:25", "new%20england%20city%20and%20town%20area%20(or%20part):71650", "necta%20division%20(or%20part):73104", "county%20(or%20part):027"]],
    ["H001001", "COUSUB:40255", ["STATE:25", "new%20england%20city%20and%20town%20area%20(or%20part):71650", "necta%20division%20(or%20part):73104", "county%20(or%20part):027"]],
    ["H001001", "UAC:*"],
    ["H001001", "UAC:00037"],
    ["H001001", "state%20(or%20part):*", ["UAC:02791"]],
    ["H001001", "state%20(or%20part):01", ["UAC:02791"]],
    ["H001001", "urban%20area%20(or%20part):*", ["STATE:*"]],
    ["H001001", "urban%20area%20(or%20part):*", ["STATE:01"]],
    ["H001001", "urban%20area%20(or%20part):32113", ["STATE:01"]],
    ["H001001", "county%20(or%20part):*", ["UAC:97119", "state%20(or%20part):01"]],
    ["H001001", "county%20(or%20part):007", ["UAC:97119", "state%20(or%20part):01"]],
    ["H001001", "county%20(or%20part):*", ["STATE:01", "urban%20area%20(or%20part):02791"]],
    ["H001001", "county%20(or%20part):043", ["STATE:01", "urban%20area%20(or%20part):02791"]],
    ["H001001", "county%20subdivision%20(or%20part):*", ["UAC:19099", "state%20(or%20part):01", "county%20(or%20part):081"]],
    ["H001001", "county%20subdivision%20(or%20part):92962", ["UAC:19099", "state%20(or%20part):01", "county%20(or%20part):081"]],
    ["H001001", "county%20subdivision%20(or%20part):*", ["STATE:49", "urban%20area%20(or%20part):50959", "county%20(or%20part):005"]],
    ["H001001", "county%20subdivision%20(or%20part):91505", ["STATE:49", "urban%20area%20(or%20part):50959", "county%20(or%20part):005"]],
    ["H001001", "place/remainder%20(or%20part):*", ["UAC:42616", "state%20(or%20part):01", "county%20(or%20part):127", "county%20subdivision%20(or%20part):91755"]],
    ["H001001", "place/remainder%20(or%20part):99999", ["UAC:42616", "state%20(or%20part):01", "county%20(or%20part):127", "county%20subdivision%20(or%20part):91755"]],
    ["H001001", "place/remainder%20(or%20part):*", ["STATE:01", "urban%20area%20(or%20part):07786", "county%20(or%20part):117", "county%20subdivision%20(or%20part):90036"]],
    ["H001001", "place/remainder%20(or%20part):00820", ["STATE:01", "urban%20area%20(or%20part):07786", "county%20(or%20part):117", "county%20subdivision%20(or%20part):90036"]],
    ["H001001", "consolidated%20city%20(or%20part):*", ["UAC:61273", "state%20(or%20part):47"]],
    ["H001001", "consolidated%20city%20(or%20part):52004", ["UAC:61273", "state%20(or%20part):47"]],
    ["H001001", "consolidated%20city%20(or%20part):*", ["STATE:47", "urban%20area%20(or%20part):61273"]],
    ["H001001", "consolidated%20city%20(or%20part):52004", ["STATE:47", "urban%20area%20(or%20part):61273"]],
    ["H001001", "place%20(or%20part):*", ["UAC:41212", "state%20(or%20part):18", "consolidated%20city%20(or%20part):36000"]],
    ["H001001", "place%20(or%20part):13492", ["UAC:41212", "state%20(or%20part):18", "consolidated%20city%20(or%20part):36000"]],
    ["H001001", "place%20(or%20part):*", ["STATE:18", "urban%20area%20(or%20part):41212", "consolidated%20city%20(or%20part):36000"]],
    ["H001001", "place%20(or%20part):72232", ["STATE:18", "urban%20area%20(or%20part):41212", "consolidated%20city%20(or%20part):36000"]],
    ["H001001", "CD:*", ["STATE:*"]],
    ["H001001", "CD:*", ["STATE:01"]],
    ["H001001", "CD:01", ["STATE:01"]],
    ["H001001", "county%20(or%20part):*", ["STATE:01", "CD:07"]],
    ["H001001", "county%20(or%20part):131", ["STATE:01", "CD:07"]],
    ["H001001", "tract%20(or%20part):*", ["STATE:01", "CD:05", "county%20(or%20part):089"]],
    ["H001001", "tract%20(or%20part):011300", ["STATE:01", "CD:05", "county%20(or%20part):089"]],
    ["H001001", "county%20subdivision%20(or%20part):*", ["STATE:18", "CD:02", "county%20(or%20part):091"]],
    ["H001001", "county%20subdivision%20(or%20part):11494", ["STATE:18", "CD:02", "county%20(or%20part):091"]],
    ["H001001", "place/remainder%20(or%20part):*", ["STATE:01", "CD:06"]],
    ["H001001", "place/remainder%20(or%20part):45208", ["STATE:01", "CD:06"]],
    ["H001001", "consolidated%20city%20(or%20part):*", ["STATE:47", "CD:07"]],
    ["H001001", "consolidated%20city%20(or%20part):52004", ["STATE:47", "CD:07"]],
    ["H001001", "place%20(or%20part):*", ["STATE:18", "CD:05", "consolidated%20city%20(or%20part):36000"]],
    ["H001001", "place%20(or%20part):84374", ["STATE:18", "CD:05", "consolidated%20city%20(or%20part):36000"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):*", ["STATE:02", "CD:00"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):6257", ["STATE:02", "CD:00"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):*", ["STATE:02", "CD:00", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):7130"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R", ["STATE:02", "CD:00", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):7130"]],
    ["H001001", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):*", ["STATE:06", "CD:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):1750"]],
    ["H001001", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T", ["STATE:06", "CD:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):1750"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):*", ["STATE:40", "CD:02", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):5550"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):135", ["STATE:40", "CD:02", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):5550"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):*", ["STATE:04", "CD:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):435", ["STATE:04", "CD:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):*", ["STATE:04", "CD:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T"]],
    ["H001001", "tribal%20subdivision/remainder%20(or%20part):170", ["STATE:04", "CD:01", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2430", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T"]],
    ["H001001", "ANRC:*", ["STATE:02", "CD:00"]],
    ["H001001", "ANRC:67940", ["STATE:02", "CD:00"]],
    ["H001001", "SLDU:*", ["STATE:*"]],
    ["H001001", "SLDU:*", ["STATE:01"]],
    ["H001001", "SLDU:007", ["STATE:01"]],
    ["H001001", "county%20(or%20part):*", ["STATE:01", "SLDU:030"]],
    ["H001001", "county%20(or%20part):001", ["STATE:01", "SLDU:030"]],
    ["H001001", "county%20subdivision%20(or%20part):*", ["STATE:17", "SLDU:054", "county%20(or%20part):159"]],
    ["H001001", "county%20subdivision%20(or%20part):29028", ["STATE:17", "SLDU:054", "county%20(or%20part):159"]],
    ["H001001", "place/remainder%20(or%20part):*", ["STATE:12", "SLDU:014"]],
    ["H001001", "place/remainder%20(or%20part):48200", ["STATE:12", "SLDU:014"]],
    ["H001001", "consolidated%20city%20(or%20part):*", ["STATE:21", "SLDU:019"]],
    ["H001001", "consolidated%20city%20(or%20part):48003", ["STATE:21", "SLDU:019"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):*", ["STATE:01", "SLDU:007"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9680", ["STATE:01", "SLDU:007"]],
    ["H001001", "SLDL:*", ["STATE:*"]],
    ["H001001", "SLDL:*", ["STATE:01"]],
    ["H001001", "SLDL:041", ["STATE:01"]],
    ["H001001", "county%20(or%20part):*", ["STATE:01", "SLDL:096"]],
    ["H001001", "county%20(or%20part):003", ["STATE:01", "SLDL:096"]],
    ["H001001", "county%20subdivision%20(or%20part):*", ["STATE:01", "SLDL:027", "county%20(or%20part):095"]],
    ["H001001", "county%20subdivision%20(or%20part):90054", ["STATE:01", "SLDL:027", "county%20(or%20part):095"]],
    ["H001001", "place/remainder%20(or%20part):*", ["STATE:28", "SLDL:035"]],
    ["H001001", "place/remainder%20(or%20part):99999", ["STATE:28", "SLDL:035"]],
    ["H001001", "consolidated%20city%20(or%20part):*", ["STATE:18", "SLDL:086"]],
    ["H001001", "consolidated%20city%20(or%20part):36000", ["STATE:18", "SLDL:086"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):*", ["STATE:01", "SLDL:006"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9680", ["STATE:01", "SLDL:006"]],
    ["H001001", "tract%20(or%20part):*", ["STATE:01", "SLDU:018", "county%20(or%20part):073"]],
    ["H001001", "tract%20(or%20part):003900", ["STATE:01", "SLDU:018", "county%20(or%20part):073"]],
    ["H001001", "alaska%20native%20regional%20corporation%20(or%20part):*", ["STATE:02", "SLDU:00F"]],
    ["H001001", "alaska%20native%20regional%20corporation%20(or%20part):17140", ["STATE:02", "SLDU:00F"]],
    ["H001001", "tract%20(or%20part):*", ["STATE:01", "SLDL:019", "county%20(or%20part):089"]],
    ["H001001", "tract%20(or%20part):000601", ["STATE:01", "SLDL:019", "county%20(or%20part):089"]],
    ["H001001", "alaska%20native%20regional%20corporation%20(or%20part):*", ["STATE:02", "SLDL:008"]],
    ["H001001", "alaska%20native%20regional%20corporation%20(or%20part):20010", ["STATE:02", "SLDL:008"]],
    ["H001001", "place/remainder%20(or%20part):*", ["STATE:18", "SLDU:029", "consolidated%20city%20(or%20part):36000"]],
    ["H001001", "place/remainder%20(or%20part):13492", ["STATE:18", "SLDU:029", "consolidated%20city%20(or%20part):36000"]],
    ["H001001", "place/remainder%20(or%20part):*", ["STATE:13", "SLDL:113", "consolidated%20city%20(or%20part):03436"]],
    ["H001001", "place/remainder%20(or%20part):09068", ["STATE:13", "SLDL:113", "consolidated%20city%20(or%20part):03436"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):*", ["STATE:01", "SLDU:008", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9680"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R", ["STATE:01", "SLDU:008", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9680"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):*", ["STATE:01", "SLDL:102", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9240"]],
    ["H001001", "american%20indian%20area/alaska%20native%20area%20(reservation%20or%20statistical%20entity%20only)%20(or%20part):R", ["STATE:01", "SLDL:102", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):9240"]],
    ["H001001", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):*", ["STATE:06", "SLDU:014", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2775"]],
    ["H001001", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T", ["STATE:06", "SLDU:014", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):2775"]],
    ["H001001", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):*", ["STATE:06", "SLDL:001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):1010"]],
    ["H001001", "american%20indian%20area%20(off-reservation%20trust%20land%20only)/hawaiian%20home%20land%20(or%20part):T", ["STATE:06", "SLDL:001", "american%20indian%20area/alaska%20native%20area/hawaiian%20home%20land%20(or%20part):1010"]],
    ["H001001", "ZCTA5:*"],
    ["H001001", "ZCTA5:00610"],
    ["H001001", "state%20(or%20part):*", ["ZCTA5:31090"]],
    ["H001001", "state%20(or%20part):13", ["ZCTA5:31090"]],
    ["H001001", "zip%20code%20tabulation%20area%20(or%20part):*", ["STATE:*"]],
    ["H001001", "zip%20code%20tabulation%20area%20(or%20part):*", ["STATE:17"]],
    ["H001001", "zip%20code%20tabulation%20area%20(or%20part):60096", ["STATE:17"]],
    ["H001001", "county%20(or%20part):*", ["ZCTA5:83522", "state%20(or%20part):16"]],
    ["H001001", "county%20(or%20part):049", ["ZCTA5:83522", "state%20(or%20part):16"]],
    ["H001001", "county%20(or%20part):*", ["STATE:12", "zip%20code%20tabulation%20area%20(or%20part):32008"]],
    ["H001001", "county%20(or%20part):121", ["STATE:12", "zip%20code%20tabulation%20area%20(or%20part):32008"]],
    ["H001001", "ELSD:*", ["STATE:*"]],
    ["H001001", "ELSD:*", ["STATE:04"]],
    ["H001001", "ELSD:06300", ["STATE:04"]],
    ["H001001", "SCSD:*", ["STATE:*"]],
    ["H001001", "SCSD:*", ["STATE:04"]],
    ["H001001", "SCSD:00082", ["STATE:04"]],
    ["H001001", "UNSD:*", ["STATE:*"]],
    ["H001001", "UNSD:*", ["STATE:01"]],
    ["H001001", "UNSD:02700", ["STATE:01"]]
  ]
end
